@@ -39,7 +39,7 @@ public class Utils {
 	/**
 	 * Hashtag regex enhanced for ticket #4937
 	 */
-	private static final String HASHTAG_REGEX = "^#\\w+([.]?\\w+)*|\\s#\\w+([.]?\\w+)*";
+	private static final String HASHTAG_REGEX = "^#\\w+([.]?\\w+)*|\\s#\\w+([.]?\\w+)*|(?<=[\\[({])#\\w+([.]?\\w+)";
 
 	/**
 	 * Pattern for URLS
@@ -49,12 +49,12 @@ public class Utils {
 					"(\\w+:\\w+@)?(([-\\w]+\\.)+(com|org|net|gov" + 
 					"|mil|biz|info|mobi|name|aero|jobs|museum" + 
 					"|travel|[a-z]{2,5}))(:[\\d]{1,5})?" + 
-					"(((\\/([-\\w~!$+|.,=]|%[a-f\\d]{2})+)+|\\/)+|\\?|#)?" + 
-					"((\\?([-\\w~!$+|.,*:]|%[a-f\\d{2}])+=?" + 
-					"([-\\w~!$+|.,*:=]|%[a-f\\d]{2})*)" + 
-					"(&(?:[-\\w~!$+|.,*:]|%[a-f\\d{2}])+=?" + 
-					"([-\\w~!$+|.,*:=]|%[a-f\\d]{2})*)*)*" + 
-			"(#([-\\w~!$+|.,*:=]|%[a-f\\d]{2})*)?\\b");
+					"(((\\/([-\\w~!$+|.,=]|%[a-fA-F\\d]{2})+)+|\\/)+|\\?|#)?" + 
+					"((\\?([-\\w~!$+|.,*:]|%[a-fA-F\\d{2}])+=?" + 
+					"([-\\w~!$+|.,*:=]|%[a-fA-F\\d]{2})*)" + 
+					"(&(?:[-\\w~!$+|.,*:]|%[a-fA-F\\d{2}])+=?" + 
+					"([-\\w~!$+|.,*:=]|%[a-fA-F\\d]{2})*)*)*" + 
+			"(#([-\\w~!$+|.,*:=]|%[a-fA-F\\d]{2})*)?\\b");
 
 	/**
 	 * 
@@ -354,7 +354,7 @@ public class Utils {
 	}
 	
 	/**
-	 * Remove HTML tags from text by using the following '\\<[^>]*>",""'
+	 * Remove HTML tags from text by using the following '\\<[^>]*>"'
 	 * @param text
 	 * @return a String without html tags
 	 */
